@@ -2,19 +2,14 @@
 
 from contextlib import suppress
 
-__version__ = "4.2.6"
-__project__ = "muffin-rest"
-__author__ = "Kirill Klenov <horneds@gmail.com>"
-__license__ = "MIT"
-
 # Default query params
 LIMIT_PARAM = "limit"
 OFFSET_PARAM = "offset"
 
 
-from .api import API  # noqa
-from .errors import APIError  # noqa
-from .handler import RESTHandler  # noqa
+from .api import API
+from .errors import APIError
+from .handler import RESTHandler
 
 # Just an alias to support legacy style
 Api = API
@@ -62,4 +57,4 @@ with suppress(ImportError):
     from .mongo.filters import MongoFilter, MongoFilters
     from .mongo.sorting import MongoSort, MongoSorting
 
-# pylama:ignore=W0611
+# ruff: noqa: E402
