@@ -2,15 +2,12 @@
 
 from __future__ import annotations
 
-from typing import Optional, Tuple, Type, TypeVar, cast
+from typing import TYPE_CHECKING, Optional, Tuple, Type, TypeVar, cast, overload
 
-import marshmallow as ma
 import peewee as pw
 from apispec.ext.marshmallow import MarshmallowPlugin
 from marshmallow_peewee import ForeignKey
-from muffin import Request
-from muffin.typing import JSONType
-from peewee_aio import Model
+from peewee_aio.model import AIOModel, ModelSelect
 
 from muffin_rest.errors import APIError
 from muffin_rest.handler import RESTBase
@@ -18,22 +15,39 @@ from muffin_rest.peewee.openapi import PeeweeOpenAPIMixin
 
 from .options import PWRESTOptions
 
+if TYPE_CHECKING:
+    import marshmallow as ma
+    from asgi_tools.types import TJSON
+    from muffin import Request
+
 # XXX: Patch apispec.MarshmallowPlugin to support ForeignKeyField
 MarshmallowPlugin.Converter.field_mapping[ForeignKey] = ("integer", None)
 
 TVModel = TypeVar("TVModel", bound=pw.Model)
 
 
-class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
+class PWRESTBase(RESTBase[TVModel], PeeweeOpenAPIMixin):
     """Support Peeweee."""
 
-    collection: pw.Query
-    resource: pw.Model
+    resource: TVModel
     meta: PWRESTOptions
     meta_class: Type[PWRESTOptions] = PWRESTOptions
+    collection: pw.ModelSelect
+
+    @overload
+    async def prepare_collection(
+        self: PWRESTBase[AIOModel], _: Request,
+    ) -> ModelSelect[TVModel]:
+        ...
+
+    @overload
+    async def prepare_collection(
+        self: PWRESTBase[pw.Model], _: Request,
+    ) -> pw.ModelSelect:
+        ...
 
     # NOTE: there is not a default sorting for peewee (conflict with muffin-admin)
-    async def prepare_collection(self, _: Request) -> pw.Query:
+    async def prepare_collection(self, _: Request):
         """Initialize Peeewee QuerySet for a binded to the resource model."""
         return self.meta.model.select()
 
@@ -47,9 +61,9 @@ class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
 
         try:
             resource = await meta.manager.fetchone(
-                self.collection.where(meta.model_pk == pk)
+                self.collection.where(meta.model_pk == pk),
             )
-        except Exception:
+        except Exception:  # noqa:
             resource = None
 
         if resource is None:
@@ -57,9 +71,19 @@ class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
 
         return resource
 
+    @overload
     async def paginate(
-        self, _: Request, *, limit: int = 0, offset: int = 0
-    ) -> Tuple[pw.Query, int]:
+        self: PWRESTBase[AIOModel], _: Request, *, limit: int = 0, offset: int = 0,
+    ) -> Tuple[ModelSelect[TVModel], int]:
+        ...
+
+    @overload
+    async def paginate(
+        self: PWRESTBase[pw.Model], _: Request, *, limit: int = 0, offset: int = 0,
+    ) -> Tuple[pw.ModelSelect, int]:
+        ...
+
+    async def paginate(self, _: Request, *, limit: int = 0, offset: int = 0):
         """Paginate the collection."""
         cqs: pw.Select = self.collection.order_by()
         if cqs._group_by:
@@ -67,7 +91,7 @@ class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
         count = await self.meta.manager.count(cqs)
         return self.collection.offset(offset).limit(limit), count
 
-    async def get(self, request, *, resource: Optional[TVModel] = None) -> JSONType:
+    async def get(self, request, *, resource: Optional[TVModel] = None) -> TJSON:
         """Get resource or collection of resources."""
         if resource is not None and resource != "":
             return await self.dump(request, resource=resource)
@@ -78,7 +102,7 @@ class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
     async def save(self, _: Request, resource: TVModel) -> TVModel:
         """Save the given resource."""
         meta = self.meta
-        if issubclass(meta.model, Model):
+        if issubclass(meta.model, AIOModel):
             await resource.save()
         else:
             await meta.manager.save(resource)
@@ -98,13 +122,13 @@ class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
 
             model_pk = cast(pw.Field, meta.model_pk)
             resources = await meta.manager.fetchall(
-                self.collection.where(model_pk << data)
+                self.collection.where(model_pk << data),
             )
 
         if not resources:
             raise APIError.NOT_FOUND()
 
-        is_aiomodel = issubclass(meta.model, Model)
+        is_aiomodel = issubclass(meta.model, AIOModel)
         if is_aiomodel:
             for res in resources:
                 await res.delete_instance(recursive=meta.delete_recursive)
@@ -115,7 +139,7 @@ class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
     delete = remove
 
     async def get_schema(
-        self, request: Request, resource: Optional[TVModel] = None, **_
+        self, request: Request, resource: Optional[TVModel] = None, **_,
     ) -> ma.Schema:
         """Initialize marshmallow schema for serialization/deserialization."""
         return self.meta.Schema(
@@ -123,3 +147,7 @@ class PWRESTHandler(RESTBase[TVModel], PeeweeOpenAPIMixin):
             only=request.url.query.get("schema_only"),
             exclude=request.url.query.get("schema_exclude", ()),
         )
+
+
+class PWRESTHandler(PWRESTBase[TVModel], PeeweeOpenAPIMixin):
+    meta: PWRESTOptions
