@@ -1,28 +1,32 @@
 """Support filters for Peewee ORM."""
+from __future__ import annotations
 
-from typing import Any, Callable, Optional, Tuple, Union, cast
+import operator
+from typing import TYPE_CHECKING, Any, Callable, Optional, Tuple, Union, cast
 
-import marshmallow as ma
-from peewee import Field, Query
+from peewee import Field, ModelSelect
 
-from ..filters import Filter, Filters
+from muffin_rest.filters import Filter, Filters
+
+if TYPE_CHECKING:
+    import marshmallow as ma
 
 
 class PWFilter(Filter):
     """Support Peewee."""
 
     operators = Filter.operators
-    operators["$in"] = lambda f, v: f << v
-    operators["$none"] = lambda f, v: f >> v
-    operators["$like"] = lambda f, v: f % v
-    operators["$ilike"] = lambda f, v: f**v
+    operators["$in"] = operator.lshift
+    operators["$none"] = operator.rshift
+    operators["$like"] = operator.mod
+    operators["$ilike"] = operator.pow
     operators["$contains"] = lambda f, v: f.contains(v)
     operators["$starts"] = lambda f, v: f.startswith(v)
     operators["$ends"] = lambda f, v: f.endswith(v)
     operators["$between"] = lambda f, v: f.between(*v)
     operators["$regexp"] = lambda f, v: f.regexp(v)
 
-    list_ops = Filter.list_ops + ["$between"]
+    list_ops = [*Filter.list_ops, "$between"]
 
     def __init__(
         self,
@@ -31,31 +35,31 @@ class PWFilter(Filter):
         field: Optional[Field] = None,
         schema_field: Optional[ma.fields.Field] = None,
         operator: Optional[str] = None,
-        **_
+        **_,
     ):
         """Support custom model fields."""
         self.name = name
         self.field = field
         self.schema_field = schema_field or self.schema_field_cls(
-            attribute=field and field.name or name
+            attribute=field and field.name or name,
         )
         if operator:
             self.default_operator = operator
 
     async def filter(
-        self, collection: Query, *ops: Tuple[Callable, Any], **kwargs
-    ) -> Query:
+        self, collection: ModelSelect, *ops: Tuple[Callable, Any], **kwargs,
+    ) -> ModelSelect:
         """Apply the filters to Peewee QuerySet.."""
         if self.field and ops:
             return self.query(collection, self.field, *ops, **kwargs)
         return collection
 
-    def query(self, query: Query, column: Field, *ops: Tuple, **_) -> Query:
+    def query(self, qs: ModelSelect, column: Field, *ops: Tuple, **_) -> ModelSelect:
         """Filter a query."""
         if isinstance(column, Field):
-            return query.where(*[op(column, val) for op, val in ops])
+            return qs.where(*[op(column, val) for op, val in ops])
 
-        return query
+        return qs
 
 
 class PWFilters(Filters):
